==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata } from "./WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata";
import { WebPaneHeaderConnectionEventArgsDescription } from "./WebPaneHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneHeaderConnectionEventArgsDescriptionMetadata, _super);
    function WebPaneHeaderConnectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneHeaderConnectionEventArgsDescriptionMetadata.a == null) {
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPaneHeaderConnectionEventArgsDetail");
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.d = function (a) {
        WebPaneHeaderConnectionEventArgsDescriptionMetadata.b(a);
        a.ac("WebPaneHeaderConnectionEventArgs", function () { return new WebPaneHeaderConnectionEventArgsDescription(); });
        a.ab("WebPaneHeaderConnectionEventArgs", WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.$t = markType(WebPaneHeaderConnectionEventArgsDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDescriptionMetadata;
}(Base));
export { WebPaneHeaderConnectionEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata } from "./WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata";
import { WebPaneHeaderConnectionEventArgsDescription } from "./WebPaneHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneHeaderConnectionEventArgsDescriptionMetadata, _super);
    function WebPaneHeaderConnectionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneHeaderConnectionEventArgsDescriptionMetadata.a == null) {
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPaneHeaderConnectionEventArgsDetail");
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.d = function (a) {
        WebPaneHeaderConnectionEventArgsDescriptionMetadata.b(a);
        a.ae("WebPaneHeaderConnectionEventArgs", function () { return new WebPaneHeaderConnectionEventArgsDescription(); });
        a.ad("WebPaneHeaderConnectionEventArgs", WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
    };
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.$t = markType(WebPaneHeaderConnectionEventArgsDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDescriptionMetadata;
}(Base));
export { WebPaneHeaderConnectionEventArgsDescriptionMetadata };
